@@ -4,7 +4,7 @@ from .inverse import (InverseOperator, read_inverse_operator, apply_inverse,
                       apply_inverse_raw, make_inverse_operator,
                       apply_inverse_epochs, write_inverse_operator,
                       compute_rank_inverse, prepare_inverse_operator,
-                      estimate_snr, apply_inverse_cov)
+                      estimate_snr, apply_inverse_cov, INVERSE_METHODS)
 from .psf_ctf import point_spread_function, cross_talk_function
 from .time_frequency import (source_band_induced_power, source_induced_power,
                              compute_source_psd, compute_source_psd_epochs)
